@@ -6,6 +6,7 @@ use pyo3::pyclass::CompareOp;
 use pyo3::types::PyTuple;
 use pyo3::types::{PyDate, PyDateTime, PyDelta, PyDeltaAccess, PyDict, PyTime, PyTzInfo};
 use pyo3::IntoPyObjectExt;
+use speedate::DateConfig;
 use speedate::{
     Date, DateTime, DateTimeConfig, Duration, MicrosecondsPrecisionOverflowBehavior, ParseError, Time, TimeConfig,
 };
@@ -21,6 +22,7 @@ use super::Input;
 use crate::errors::ToErrorValue;
 use crate::errors::{ErrorType, ValError, ValResult};
 use crate::tools::py_err;
+use crate::validators::TemporalUnitMode;
 
 #[cfg_attr(debug_assertions, derive(Debug))]
 pub enum EitherDate<'py> {
@@ -71,7 +73,7 @@ impl<'py> EitherDate<'py> {
 
     pub fn as_raw(&self) -> PyResult<Date> {
         match self {
-            Self::Raw(date) => Ok(date.clone()),
+            Self::Raw(date) => Ok(*date),
             Self::Py(py_date) => pydate_as_date(py_date),
         }
     }
@@ -332,7 +334,7 @@ impl<'py> IntoPyObject<'py> for EitherTime<'py> {
 impl EitherTime<'_> {
     pub fn as_raw(&self) -> PyResult<Time> {
         match self {
-            Self::Raw(time) => Ok(time.clone()),
+            Self::Raw(time) => Ok(*time),
             Self::Py(py_time) => pytime_as_time(py_time, None),
         }
     }
@@ -405,14 +407,18 @@ impl<'py> EitherDateTime<'py> {
 
     pub fn as_raw(&self) -> PyResult<DateTime> {
         match self {
-            Self::Raw(dt) => Ok(dt.clone()),
+            Self::Raw(dt) => Ok(*dt),
             Self::Py(py_dt) => pydatetime_as_datetime(py_dt),
         }
     }
 }
 
-pub fn bytes_as_date<'py>(input: &(impl Input<'py> + ?Sized), bytes: &[u8]) -> ValResult<EitherDate<'py>> {
-    match Date::parse_bytes(bytes) {
+pub fn bytes_as_date<'py>(
+    input: &(impl Input<'py> + ?Sized),
+    bytes: &[u8],
+    mode: TemporalUnitMode,
+) -> ValResult<EitherDate<'py>> {
+    match Date::parse_bytes_with_config(bytes, &DateConfig::builder().timestamp_unit(mode.into()).build()) {
         Ok(date) => Ok(date.into()),
         Err(err) => Err(ValError::new(
             ErrorType::DateParsing {
@@ -451,6 +457,7 @@ pub fn bytes_as_datetime<'py>(
     input: &(impl Input<'py> + ?Sized),
     bytes: &[u8],
     microseconds_overflow_behavior: MicrosecondsPrecisionOverflowBehavior,
+    mode: TemporalUnitMode,
 ) -> ValResult<EitherDateTime<'py>> {
     match DateTime::parse_bytes_with_config(
         bytes,
@@ -459,7 +466,7 @@ pub fn bytes_as_datetime<'py>(
                 microseconds_precision_overflow_behavior: microseconds_overflow_behavior,
                 unix_timestamp_offset: Some(0),
             },
-            ..Default::default()
+            timestamp_unit: mode.into(),
         },
     ) {
         Ok(dt) => Ok(dt.into()),
@@ -477,6 +484,7 @@ pub fn int_as_datetime<'py>(
     input: &(impl Input<'py> + ?Sized),
     timestamp: i64,
     timestamp_microseconds: u32,
+    mode: TemporalUnitMode,
 ) -> ValResult<EitherDateTime<'py>> {
     match DateTime::from_timestamp_with_config(
         timestamp,
@@ -486,7 +494,7 @@ pub fn int_as_datetime<'py>(
                 unix_timestamp_offset: Some(0),
                 ..Default::default()
             },
-            ..Default::default()
+            timestamp_unit: mode.into(),
         },
     ) {
         Ok(dt) => Ok(dt.into()),
@@ -514,12 +522,31 @@ macro_rules! nan_check {
     };
 }
 
-pub fn float_as_datetime<'py>(input: &(impl Input<'py> + ?Sized), timestamp: f64) -> ValResult<EitherDateTime<'py>> {
+pub fn float_as_datetime<'py>(
+    input: &(impl Input<'py> + ?Sized),
+    timestamp: f64,
+    mode: TemporalUnitMode,
+) -> ValResult<EitherDateTime<'py>> {
     nan_check!(input, timestamp, DatetimeParsing);
-    let microseconds = timestamp.fract().abs() * 1_000_000.0;
-    // checking for extra digits in microseconds is unreliable with large floats,
-    // so we just round to the nearest microsecond
-    int_as_datetime(input, timestamp.floor() as i64, microseconds.round() as u32)
+    match DateTime::from_float_with_config(
+        timestamp,
+        &DateTimeConfig {
+            time_config: TimeConfig {
+                unix_timestamp_offset: Some(0),
+                ..Default::default()
+            },
+            timestamp_unit: mode.into(),
+        },
+    ) {
+        Ok(dt) => Ok(dt.into()),
+        Err(err) => Err(ValError::new(
+            ErrorType::DatetimeParsing {
+                error: Cow::Borrowed(err.get_documentation().unwrap_or_default()),
+                context: None,
+            },
+            input,
+        )),
+    }
 }
 
 pub fn date_as_datetime<'py>(date: &Bound<'py, PyDate>) -> PyResult<EitherDateTime<'py>> {
@@ -643,6 +670,7 @@ pub struct TzInfo {
 #[pymethods]
 impl TzInfo {
     #[new]
+    #[pyo3(signature = (seconds = 0.0))]
     fn py_new(seconds: f32) -> PyResult<Self> {
         Self::try_from(seconds.trunc() as i32)
     }
