@@ -28,10 +28,10 @@ pub(crate) struct SerializationState {
 }
 
 impl SerializationState {
-    pub fn new(timedelta_mode: &str, bytes_mode: &str, inf_nan_mode: &str) -> PyResult<Self> {
+    pub fn new(timedelta_mode: &str, temporal_mode: &str, bytes_mode: &str, inf_nan_mode: &str) -> PyResult<Self> {
         let warnings = CollectWarnings::new(WarningsMode::None);
         let rec_guard = SerRecursionState::default();
-        let config = SerializationConfig::from_args(timedelta_mode, bytes_mode, inf_nan_mode)?;
+        let config = SerializationConfig::from_args(timedelta_mode, temporal_mode, bytes_mode, inf_nan_mode)?;
         Ok(Self {
             warnings,
             rec_guard,
@@ -60,6 +60,7 @@ impl SerializationState {
             false,
             false,
             exclude_none,
+            false,
             round_trip,
             &self.config,
             &self.rec_guard,
@@ -86,6 +87,7 @@ pub(crate) struct Extra<'a> {
     pub exclude_unset: bool,
     pub exclude_defaults: bool,
     pub exclude_none: bool,
+    pub exclude_computed_fields: bool,
     pub round_trip: bool,
     pub config: &'a SerializationConfig,
     pub rec_guard: &'a SerRecursionState,
@@ -112,6 +114,7 @@ impl<'a> Extra<'a> {
         exclude_unset: bool,
         exclude_defaults: bool,
         exclude_none: bool,
+        exclude_computed_fields: bool,
         round_trip: bool,
         config: &'a SerializationConfig,
         rec_guard: &'a SerRecursionState,
@@ -128,6 +131,7 @@ impl<'a> Extra<'a> {
             exclude_unset,
             exclude_defaults,
             exclude_none,
+            exclude_computed_fields,
             round_trip,
             config,
             rec_guard,
@@ -196,6 +200,7 @@ pub(crate) struct ExtraOwned {
     exclude_unset: bool,
     exclude_defaults: bool,
     exclude_none: bool,
+    exclude_computed_fields: bool,
     round_trip: bool,
     config: SerializationConfig,
     rec_guard: SerRecursionState,
@@ -217,6 +222,7 @@ impl ExtraOwned {
             exclude_unset: extra.exclude_unset,
             exclude_defaults: extra.exclude_defaults,
             exclude_none: extra.exclude_none,
+            exclude_computed_fields: extra.exclude_computed_fields,
             round_trip: extra.round_trip,
             config: extra.config.clone(),
             rec_guard: extra.rec_guard.clone(),
@@ -239,6 +245,7 @@ impl ExtraOwned {
             exclude_unset: self.exclude_unset,
             exclude_defaults: self.exclude_defaults,
             exclude_none: self.exclude_none,
+            exclude_computed_fields: self.exclude_computed_fields,
             round_trip: self.round_trip,
             config: &self.config,
             rec_guard: &self.rec_guard,
