@@ -60,6 +60,7 @@ impl SchemaSerializer {
         exclude_unset: bool,
         exclude_defaults: bool,
         exclude_none: bool,
+        exclude_computed_fields: bool,
         round_trip: bool,
         rec_guard: &'a SerRecursionState,
         serialize_unknown: bool,
@@ -75,6 +76,7 @@ impl SchemaSerializer {
             exclude_unset,
             exclude_defaults,
             exclude_none,
+            exclude_computed_fields,
             round_trip,
             &self.config,
             rec_guard,
@@ -108,8 +110,8 @@ impl SchemaSerializer {
 
     #[allow(clippy::too_many_arguments)]
     #[pyo3(signature = (value, *, mode = None, include = None, exclude = None, by_alias = None,
-        exclude_unset = false, exclude_defaults = false, exclude_none = false, round_trip = false, warnings = WarningsArg::Bool(true),
-        fallback = None, serialize_as_any = false, context = None))]
+        exclude_unset = false, exclude_defaults = false, exclude_none = false, exclude_computed_fields = false,
+        round_trip = false, warnings = WarningsArg::Bool(true), fallback = None, serialize_as_any = false, context = None))]
     pub fn to_python(
         &self,
         py: Python,
@@ -121,6 +123,7 @@ impl SchemaSerializer {
         exclude_unset: bool,
         exclude_defaults: bool,
         exclude_none: bool,
+        exclude_computed_fields: bool,
         round_trip: bool,
         warnings: WarningsArg,
         fallback: Option<&Bound<'_, PyAny>>,
@@ -142,6 +145,7 @@ impl SchemaSerializer {
             exclude_unset,
             exclude_defaults,
             exclude_none,
+            exclude_computed_fields,
             round_trip,
             &rec_guard,
             false,
@@ -156,8 +160,8 @@ impl SchemaSerializer {
 
     #[allow(clippy::too_many_arguments)]
     #[pyo3(signature = (value, *, indent = None, ensure_ascii = false, include = None, exclude = None, by_alias = None,
-        exclude_unset = false, exclude_defaults = false, exclude_none = false, round_trip = false, warnings = WarningsArg::Bool(true),
-        fallback = None, serialize_as_any = false, context = None))]
+        exclude_unset = false, exclude_defaults = false, exclude_none = false, exclude_computed_fields = false,
+        round_trip = false, warnings = WarningsArg::Bool(true), fallback = None, serialize_as_any = false, context = None))]
     pub fn to_json(
         &self,
         py: Python,
@@ -170,6 +174,7 @@ impl SchemaSerializer {
         exclude_unset: bool,
         exclude_defaults: bool,
         exclude_none: bool,
+        exclude_computed_fields: bool,
         round_trip: bool,
         warnings: WarningsArg,
         fallback: Option<&Bound<'_, PyAny>>,
@@ -190,6 +195,7 @@ impl SchemaSerializer {
             exclude_unset,
             exclude_defaults,
             exclude_none,
+            exclude_computed_fields,
             round_trip,
             &rec_guard,
             false,
@@ -241,9 +247,9 @@ impl SchemaSerializer {
 #[allow(clippy::too_many_arguments)]
 #[pyfunction]
 #[pyo3(signature = (value, *, indent = None, ensure_ascii = false, include = None, exclude = None, by_alias = true,
-    exclude_none = false, round_trip = false, timedelta_mode = "iso8601", bytes_mode = "utf8",
-    inf_nan_mode = "constants", serialize_unknown = false, fallback = None, serialize_as_any = false,
-    context = None))]
+    exclude_none = false, round_trip = false, timedelta_mode = "iso8601", temporal_mode = "iso8601",
+    bytes_mode = "utf8",  inf_nan_mode = "constants", serialize_unknown = false, fallback = None,
+    serialize_as_any = false, context = None))]
 pub fn to_json(
     py: Python,
     value: &Bound<'_, PyAny>,
@@ -255,6 +261,7 @@ pub fn to_json(
     exclude_none: bool,
     round_trip: bool,
     timedelta_mode: &str,
+    temporal_mode: &str,
     bytes_mode: &str,
     inf_nan_mode: &str,
     serialize_unknown: bool,
@@ -262,7 +269,7 @@ pub fn to_json(
     serialize_as_any: bool,
     context: Option<&Bound<'_, PyAny>>,
 ) -> PyResult<PyObject> {
-    let state = SerializationState::new(timedelta_mode, bytes_mode, inf_nan_mode)?;
+    let state = SerializationState::new(timedelta_mode, temporal_mode, bytes_mode, inf_nan_mode)?;
     let extra = state.extra(
         py,
         &SerMode::Json,
@@ -292,8 +299,8 @@ pub fn to_json(
 #[allow(clippy::too_many_arguments)]
 #[pyfunction]
 #[pyo3(signature = (value, *, include = None, exclude = None, by_alias = true, exclude_none = false, round_trip = false,
-    timedelta_mode = "iso8601", bytes_mode = "utf8", inf_nan_mode = "constants", serialize_unknown = false, fallback = None,
-    serialize_as_any = false, context = None))]
+    timedelta_mode = "iso8601", temporal_mode = "iso8601", bytes_mode = "utf8", inf_nan_mode = "constants",
+    serialize_unknown = false, fallback = None, serialize_as_any = false, context = None))]
 pub fn to_jsonable_python(
     py: Python,
     value: &Bound<'_, PyAny>,
@@ -303,6 +310,7 @@ pub fn to_jsonable_python(
     exclude_none: bool,
     round_trip: bool,
     timedelta_mode: &str,
+    temporal_mode: &str,
     bytes_mode: &str,
     inf_nan_mode: &str,
     serialize_unknown: bool,
@@ -310,7 +318,7 @@ pub fn to_jsonable_python(
     serialize_as_any: bool,
     context: Option<&Bound<'_, PyAny>>,
 ) -> PyResult<PyObject> {
-    let state = SerializationState::new(timedelta_mode, bytes_mode, inf_nan_mode)?;
+    let state = SerializationState::new(timedelta_mode, temporal_mode, bytes_mode, inf_nan_mode)?;
     let extra = state.extra(
         py,
         &SerMode::Json,
