@@ -15,7 +15,7 @@ from typing import Any, Callable, Literal
 import hypothesis
 import pytest
 
-from pydantic_core import ArgsKwargs, CoreSchema, SchemaValidator, ValidationError, validate_core_schema
+from pydantic_core import ArgsKwargs, CoreSchema, SchemaValidator, ValidationError
 from pydantic_core.core_schema import CoreConfig
 
 __all__ = 'Err', 'PyAndJson', 'assert_gc', 'is_free_threaded', 'plain_repr', 'infinite_generator'
@@ -64,7 +64,7 @@ class PyAndJsonValidator:
         *,
         validator_type: Literal['json', 'python'] | None = None,
     ):
-        self.validator = SchemaValidator(validate_core_schema(schema), config)
+        self.validator = SchemaValidator(schema, config)
         self.validator_type = validator_type
 
     def validate_python(self, py_input, strict: bool | None = None, context: Any = None):
