@@ -2,14 +2,10 @@ import dataclasses
 import json
 import platform
 import warnings
+from functools import cached_property
 from random import randint
 from typing import Any, ClassVar
 
-try:
-    from functools import cached_property
-except ImportError:
-    cached_property = None
-
 import pytest
 from dirty_equals import IsJson
 
@@ -504,7 +500,6 @@ def test_function_plain_field_serializer_to_python():
     assert s.to_python(Model(x=1000)) == {'x': '1_000'}
 
 
-@pytest.mark.skipif(cached_property is None, reason='cached_property is not available')
 def test_field_serializer_cached_property():
     @dataclasses.dataclass
     class Model:
@@ -709,6 +704,9 @@ def test_property():
     assert s.to_python(Model(width=3, height=4), round_trip=True) == {'width': 3, 'height': 4}
     assert s.to_json(Model(width=3, height=4), round_trip=True) == b'{"width":3,"height":4}'
 
+    assert s.to_python(Model(width=3, height=4), exclude_computed_fields=True) == {'width': 3, 'height': 4}
+    assert s.to_json(Model(width=3, height=4), exclude_computed_fields=True) == b'{"width":3,"height":4}'
+
 
 def test_property_alias():
     @dataclasses.dataclass
@@ -744,6 +742,34 @@ def test_property_alias():
     assert s.to_json(Model(3, 4), by_alias=True) == b'{"width":3,"height":4,"Area":12,"volume":48}'
 
 
+def test_computed_field_without_fields() -> None:
+    """https://github.com/pydantic/pydantic/issues/5551"""
+
+    # Original test introduced in https://github.com/pydantic/pydantic-core/pull/550
+
+    class A:
+        @property
+        def b(self) -> str:
+            return 'b'
+
+    schema = core_schema.model_schema(
+        cls=A,
+        config={},
+        schema=core_schema.model_fields_schema(
+            fields={},
+            computed_fields=[
+                core_schema.computed_field('b', return_schema=core_schema.any_schema()),
+            ],
+        ),
+    )
+
+    a = A()
+
+    serializer = SchemaSerializer(schema)
+
+    assert serializer.to_json(a) == b'{"b":"b"}'
+
+
 def test_computed_field_exclude_none():
     @dataclasses.dataclass
     class Model:
@@ -853,7 +879,6 @@ def test_computed_field_exclude_none_different_order():
     assert s.to_json(Model(3, 4), exclude_none=True, by_alias=True) == b'{"width":3,"height":4,"Area":12}'
 
 
-@pytest.mark.skipif(cached_property is None, reason='cached_property is not available')
 def test_cached_property_alias():
     @dataclasses.dataclass
     class Model:
@@ -968,7 +993,6 @@ def test_property_include_exclude():
     assert s.to_json(Model(1), exclude={'b': [0]}) == b'{"a":1,"b":[2,"3"]}'
 
 
-@pytest.mark.skipif(cached_property is None, reason='cached_property is not available')
 def test_property_setter():
     class Square:
         side: float
